#!/bin/bash
# Copyright (c) 2013, xopr@ackspace.nl
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met: 
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer. 
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution. 
#
# USE THIS SOFTWARE AT YOUR OWN RISK

IP=192.168.178.16
PORT=2000

declare -A FIRMWARES=()
FIRMWARES[SIP]=P0S3-8-12-00
FIRMWARES[SEP]=P00308000600

declare -A NAMES=()
NAMES[SIP]=SIP
NAMES[SEP]=SCCP

echo -e "\xE2\x98\xA0 warning, use at your own risk \xE2\x98\xA0"
echo    "  This will overwrite the designated config files without confirmation!"
if [[ $* == -h || $* == -? || $* == --help ]]; then
    echo -e "\tusage: $0 {SEP|SIP}<mac address>"
    echo
    echo -e "\tthis will create both type of Cisco IP7900 series config files"
    echo -e "\teither for loading SIP or SEP (SCCP 'skinny') firmware"
    echo
    exit 0
fi


function createSIP
{
    echo SIP$2.cnf

    result=
    while IFS= read -r line; do
        line="${line//'[FIRMWARE]'/${FIRMWARES[$1]}}"
        line="${line//'[IP]'/$IP}"
        line="${line//'[PORT]'/$PORT}"
        result="$result""$line"'\n'
    done < SIP.cnf
    echo -e $result > SIP$2.cnf
}

function createSEP
{
    echo SEP$2.cnf.xml

    result=
    while IFS= read -r line; do
        line="${line//'[FIRMWARE]'/${FIRMWARES[$1]}}"
        line="${line//'[IP]'/$IP}"
        line="${line//'[PORT]'/$PORT}"
        result="$result""$line"'\n'
    done < SEP.cnf.xml
    echo -e $result > SEP$2.cnf.xml
}


if [[ ! -f SIP.cnf || ! -f SEP.cnf.xml ]]; then
    echo "ERROR:"
    echo "Make sure the SIP.cnf and SEP.cnf.xml template files are in this directory as well."
    echo "You can recognize the template file by the variable names"
    echo "[FIRMWARE], [IP] and/or [PORT] in them"
    echo
    exit 1
fi



# something will break when using * in source file
is_nullglob=$( shopt -s | egrep -i '*nullglob' )
if [[ is_nullglob ]]; then
   shopt -u nullglob
fi

# case insensitive search: sip0123456789AB OR sep0123456789ab
regexp='^(S[IE]P)?[ ]*([0-9A-F]{12})?$'

if [[ ${*^^} =~ $regexp ]]; then
    proto=${BASH_REMATCH[1]}
    mac=${BASH_REMATCH[2]}

    if [ -z "$proto" ]; then
        read -n1 -p "SIP (i) or Skinny (e)? " proto
        echo
        if [ $proto == "e" ]; then
            proto="SEP"
        else
            proto="SIP"
        fi
    fi

    if [[ -z $mac ]]; then echo "Enter MAC address: "; fi
    while [[ ${#mac} -lt 12 ]]; do
        read -n1 -s digit
        regexp='([0-9a-fA-F])+'
        if [[ ${digit^^} =~ $regexp ]]; then
            mac=$mac${BASH_REMATCH[1]}
            echo -n ${BASH_REMATCH[1]}
        fi
    done
    echo
fi

echo -e "Creating configuration files for ${NAMES[$proto]} firmware:"
createSIP $proto $mac
createSEP $proto $mac
echo "if the universal loader doesn't load the new firmware, take the following steps:"
echo "-reset the phone by powering it up while holding '#'"
echo "-when 'reset sequence detected' is visible, type 123456789*0#"
echo "-followed by 2 (erase network configuration)"

if [[ is_nullglob ]]; then
   shopt -s nullglob
fi
